package org.jabricks.basegui.examples;

import javax.swing.*;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.io.File;
import java.lang.reflect.Method;

import java.util.Locale;
import java.util.Properties;

import java.net.URL;
import java.net.URLClassLoader;

import org.jabricks.basegui.grid.Grid;
import org.jabricks.basegui.grid.IGrid;

public class ExampleGrid extends JFrame
{
	private static final long serialVersionUID = 1L;
	
	private IGrid  grid;
	
	private Object[][] drink = 
                   {{ "Пиво бут. 0.5",   5,  50,  250},
                    { "Пиво бан. 0.5",  12,  60,  720},
                    { "Пиво бут. 2.0",   5, 160,  800},
                    { "Байкал 2.0"   ,  10,  75,  750},
                    { "Байкал 1.0"   , -10,  39,  390},
                    { "Coca-cola 1.5",   5,  60,  300},
                    { "Coca-cola 2.0",   5,  78,  390},
                    { "Водка 0.5"    ,   4, 350, 1400},
                    { "Виски 0.5"    ,   1, 980,  980},
                    { "Коньяк 0.5"   ,   1, 890,  890},
                    { "Молоко 0.9"   ,   2,  55,  110},
                    { "Кефир 0.5"    ,   2,  55,  110},
                    { "Ряженка 0.5"  ,   2,  45,   90}};
	private int        added_idx = 0; 
	private Object[][] drink_add = 
                   {{ "Йогурт 0.5"   ,  4, 55, 220},
                    { "Йогурт 0.25"  ,  6, 35, 210},
                    { "Йогурт 1.0"   ,  2, 95, 180},
                    { "Кефир 0.5"    ,  2, 45,  90}
                    };
	private Class<?>[] classes_drink = {String.class, Integer.class, Integer.class, Integer.class};

	private String [] drinkNames  = {"name", "quantity", "price", "cost"};
    private Integer[] drink_align = {JLabel.LEFT, JLabel.RIGHT, JLabel.RIGHT, JLabel.RIGHT};
	
	Locale  locale = new Locale("ru");	
	private String [][] COLUMN_LOCALES = {{"Наименование", "Количество", "Цена", "Стоимость"},
		                                  {"Name", "Quantity", "Price", "Cost"}};
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public ExampleGrid()
	{
		super("Grid example");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

        createGid();
	
		getContentPane().add(grid.asWidget (), BorderLayout.CENTER);
		getContentPane().add(createControls(), BorderLayout.SOUTH);
		setSize(520, 360);

		// Загрузка данных
		grid.addRecords(drink);

		setVisible(true);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createGid()
	{
		// Создание таблицы
		grid = new Grid(classes_drink, drinkNames, getColumnNames());
		// Настройка таблицы
		grid.setColumnsAlign(drink_align);
		grid.setReorderingAllowed(false);
		grid.setColumnsWidth(new int[] {220, 90, 90, 80});
		grid.setDefaultRenderer(Integer.class, new IntegerRenderer());
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private JPanel createControls()
	{
		JButton btnLocale = new JButton("Изменение языка локализации");
		btnLocale.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				if (locale.getLanguage().equalsIgnoreCase("ru"))
					locale = new Locale("en");
				else
					locale = new Locale("ru");
				Properties props = getColumnProps();
				grid.setLocale(props);
			}
		});
		JButton btnAdd = new JButton("Добавить запись");
		btnAdd.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				addRecord();
			}
		});
		
		JButton btnDel = new JButton("Удалить запись");
		btnDel.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				deleteRecord();
			}
		});
		// Панель кнопок управления
		JPanel pnlButtons = new JPanel();
		pnlButtons.add(btnLocale );
		pnlButtons.add(btnAdd    );
		pnlButtons.add(btnDel    );
		
		return pnlButtons;
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private String[] getColumnNames()
	{
		String[] names = new String[drinkNames.length];
		int idx = 1;
		if (locale.getLanguage().equalsIgnoreCase("ru"))
			idx = 0;

		for (int i = 0; i < drinkNames.length; i++)
			names[i] = COLUMN_LOCALES[idx][i];
		return names;
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private Properties getColumnProps()
	{
		Properties props = new Properties();
		int idx = 1;
		if (locale.getLanguage().equalsIgnoreCase("ru"))
			idx = 0;

		for (int i = 0; i < drinkNames.length; i++)
			props.setProperty(drinkNames[i], COLUMN_LOCALES[idx][i]);
		return props;
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	/**
	 * Процедура добавления записи
	 * Новая запись добавляется в коллекцию drink_data
	 */
	private void addRecord()
	{
		if (added_idx <= (drink_add.length - 1))
			grid.addRecord(drink_add[added_idx++]);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	/**
	 * Процедура отладки удаления записи из таблицы
	 */
	private void deleteRecord()
	{
		// Удаляемая строка
		int row = grid.getTable().getSelectedRow();
		if (row >= 0) {
			grid.delRecord(row);
		}
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public static void main(String[] args) {
		new ExampleGrid();
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
}